<?php defined("SYSPATH") or die("No direct script access.");

class lrplugin_rest_Core {

    static function get($request) {
        switch ($request->params->action) {
        case "getUser":
            $user = self::_resolve_user($request->params->id);

            return array(
                "module" => "lrplugin",
                "api_version" => module::get_version("lrplugin_rest"),
                "entity" => array(
                    "display_name" => $user->display_name(),
                    "id" => $user->id,
                    "email" => $user->email,
                ),
            );

        case "getInfo":
            return array(
                "module" => "lrplugin",
                "api_version" => module::get_version("lrplugin_rest"),
            );

        default:
            throw new Rest_Exception("Bad Request", 400, array("errors" => array("action" => "invalid")));
        }
    }

    static function put($request) {
        switch ($request->params->action) {
        case "makeAlbumCover":
            $item = rest::resolve($request->params->item);
            $entity = $request->params->entity;

            if (!property_exists($entity, "album_cover")) {
                throw new Rest_Exception("Bad Request", 400, array("errors" => array("album_cover" => "missing")));
            }

            $album_cover_item = rest::resolve($entity->album_cover);
            access::required("view", $album_cover_item);
            $item->album_cover_item_id = $album_cover_item->id;
            item::make_album_cover($album_cover_item);

            $item->save();

            return array(  
                "result" => "success",
                "entity" => $item->as_restful_array(), 
            );

        case "itemTags":
            $item = rest::resolve($request->params->item);

            if (!property_exists($request->params, "tags")) {
                throw new Rest_Exception("Bad Request", 400, array("tags" => array("tags" => "missing")));
            }

            // unlink the item from its tags
            tag::clear_all($item);

            // associate the item with new tags
            foreach (explode(",", $request->params->tags) as $tag_name) {
                $tag_name = trim($tag_name);
                if ($tag_name) {
                    $tag = tag::add($item, $tag_name);
                }
            }

            // remove unused tags
            tag::compact();

            return array(  
                "result" => "success",
                "relationships" => rest::relationships("item", $item)
            );

        default:
            throw new Rest_Exception("Bad Request", 400, array("errors" => array("action" => "invalid")));
        }
    }

    static protected function _resolve_user($id) {
        if (empty($id)) {
            // Currently logged in user
            $id = identity::active_user()->id;
        }

        $user = identity::lookup_user($id);

        if (!self::_can_view_profile_pages($user)) {
            throw new Kohana_404_Exception();
        }

        return $user;
    }


    static protected function _can_view_profile_pages($user) {
        if (!$user->loaded()) {
            return false;
        }

        if ($user->id == identity::active_user()->id) {
            // You can always view your own profile
            return true;
        }

        switch (module::get_var("gallery", "show_user_profiles_to")) {
        case "admin_users":
            return identity::active_user()->admin;

        case "registered_users":
            return !identity::active_user()->guest;

        case "everybody":
            return true;

        default:
            // Fail in private mode on an invalid setting
            return false;
        }
    }
}
